@@ -33,6 +33,12 @@ class Calendar : public QDialog, public Ui::Calendar {
 
     signals:
      void aDateWasSet();
+     void starting();
+     void finishing();
+
+    protected:
+     virtual void showEvent(QShowEvent* show_);
+     virtual void closeEvent(QCloseEvent* close_);
 
 };
 
