@@ -29,6 +29,8 @@ class Editor : public QDialog, public Ui::Editor {
 
     signals:
      void saved();
+     void starting();
+     void finishing();
 
     private:
      QFile *confFile;
@@ -38,6 +40,7 @@ class Editor : public QDialog, public Ui::Editor {
 
     protected:
      virtual void showEvent(QShowEvent* show_editor);
+     virtual void closeEvent(QCloseEvent* window_close);
      void keyPressEvent(QKeyEvent* kEvent);
 
 };
