@@ -51,6 +51,9 @@ Gui::Gui(QWidget *parent): QWidget(parent){
 
      setWindowFlags(Qt::WindowStaysOnTopHint);
 
+     minimize = QString(tr("&Minimize"));
+     restore = QString(tr("Res&tore"));
+
    //Preferences
      pref = new Preferences(this);
 
@@ -88,21 +91,22 @@ Gui::Gui(QWidget *parent): QWidget(parent){
 
    //TrayIconContextMenu
      menu = new QMenu(this);
-     reset_action = new QAction(tr("R&eset \t Ctrl+E"),this);
-     quit_action = new QAction(tr("&Quit \t Ctrl+Q"),this);
-     info_action = new QAction(tr("&Info \t Ctrl+I"),this);
-     log_action = new QAction(tr("&Logfile \t Ctrl+L"),this);
+     minimize_restore_action = new QAction(minimize,this);
+     reset_action = new QAction(tr("R&eset"),this);
+     quit_action = new QAction(tr("&Quit"),this);
+     info_action = new QAction(tr("&Info"),this);
+     log_action = new QAction(tr("&Logfile"),this);
      log_action->setCheckable(true);
-     pref_action = new QAction(tr("&Preferences \t Ctrl+P"),this);
+     pref_action = new QAction(tr("&Preferences"),this);
 
      power_actions = new QActionGroup(this);
-     shutdown_action = new QAction(tr("&Shutdown \t Ctrl+S"),this);
+     shutdown_action = new QAction(tr("&Shutdown"),this);
      shutdown_action->setCheckable(true);
-     reboot_action = new QAction(tr("&Reboot \t Ctrl+R"),this);
+     reboot_action = new QAction(tr("&Reboot"),this);
      reboot_action->setCheckable(true);
-     suspend_action = new QAction(tr("S&uspend \t Ctrl+U"),this);
+     suspend_action = new QAction(tr("S&uspend"),this);
      suspend_action->setCheckable(true);
-     hibernate_action = new QAction(tr("&Hibernate \t Ctrl+H"),this);
+     hibernate_action = new QAction(tr("&Hibernate"),this);
      hibernate_action->setCheckable(true);
      power_actions->addAction(shutdown_action);
      power_actions->addAction(reboot_action);
@@ -120,6 +124,7 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      menu->addAction(hibernate_action);
      reset_action->setVisible(false);
      menu->addSeparator();
+     menu->addAction(minimize_restore_action);
      menu->addAction(quit_action);
      
      TIcon->setContextMenu(menu);  //setting contextmenu for the systray
@@ -165,6 +170,7 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      connect(power_actions, SIGNAL(triggered(QAction*)), this, SLOT(power(QAction*)));
      connect(reset_action, SIGNAL(triggered()), this, SLOT(reset()));
      connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(beforeQuit())); //save window size / logs and unregister qshutdown
+     connect(minimize_restore_action, SIGNAL(triggered()), this, SLOT(tray_actions()));
      connect(quit_action, SIGNAL(triggered()), qApp, SLOT(quit())); //contextmenu "Quit" for the systray quits Programm
 
      connect(pref_action, SIGNAL(triggered()), pref, SLOT(show()));
@@ -195,6 +201,17 @@ Gui::Gui(QWidget *parent): QWidget(parent){
 
 Gui::~Gui(){ delete font1; delete font2; delete font3; }
 
+void Gui::tray_actions(){
+     if(isMinimized() || isHidden()){  //in case that the window is minimized or hidden
+       showNormal();
+       minimize_restore_action->setText(minimize);
+     }
+     else{
+       hide();
+       minimize_restore_action->setText(restore);
+     }
+}
+
 void Gui::setInfoText(){ infoBox->setHtml(information); }
 
 void Gui::warnings_on(){
@@ -213,10 +230,7 @@ void Gui::center(){
 
 void Gui::iconActivated(QSystemTrayIcon::ActivationReason reason){
      if(reason == QSystemTrayIcon::Trigger){
-       if(isHidden()||isMinimized())  //in case thant the window is minimized or hidden
-         showNormal();
-       else
-         hide();
+       tray_actions(); //hide or show
      }
 }
 
@@ -256,14 +270,18 @@ void Gui::power(QAction *action){
 }
 
 void Gui::showW(){
-     if(warnings->isChecked()) //warnings is checked
+     if(warnings->isChecked()){ //warnings is checked
        showRunningProgram();
+       minimize_restore_action->setText(minimize);
+     }
 }
 
 void Gui::showRunningProgram(){
      center();
-     if(isMinimized() || isHidden())
+     if(isMinimized() || isHidden()){
        showNormal();
+       minimize_restore_action->setText(minimize);
+     }
      else
        activateWindow();
 }
@@ -503,10 +521,12 @@ void Gui::finished_(){
          break;
        default:;
      }
+     qApp->quit();
 }
 
 void Gui::closeEvent(QCloseEvent* window_close){
      hide();
+     minimize_restore_action->setText(minimize);
      QWidget::closeEvent(window_close);
 }
 
@@ -629,8 +649,10 @@ void Gui::loadSettings(){
 
      if(settings.value("Time/countdown_at_startup").toBool()){
        set();
-       if(settings.value("Hide_at_startup").toBool())
+       if(settings.value("Hide_at_startup").toBool()){
          QTimer::singleShot(2000, this, SLOT(hide()));
+         minimize_restore_action->setText(restore);
+       }
      }
 
      if(settings.value("Lock_all").toBool()){
