@@ -42,6 +42,7 @@ class Gui : public QWidget, public Ui::Gui {
      void loadSettings();
      void center();
      QString information;
+     QString minimize, restore;
  
     private:
      QPushButton     *minim;
@@ -55,15 +56,11 @@ class Gui : public QWidget, public Ui::Gui {
      QSystemTrayIcon *TIcon;
      QMenu           *menu;
      QActionGroup    *power_actions;
-     QAction         *shutdown_action;
-     QAction         *reboot_action;
-     QAction         *suspend_action;
-     QAction         *hibernate_action;
-     QAction         *quit_action;
-     QAction         *reset_action;
-     QAction         *info_action;
-     QAction         *log_action;
-     QAction         *pref_action;
+     QAction         *shutdown_action, *reboot_action,
+                     *suspend_action, *hibernate_action;
+     QAction         //*minimize_action, *restore_action,
+ *minimize_restore_action, *quit_action,
+                     *reset_action, *info_action, *log_action, *pref_action;
      int             i; //number of seconds left
      int             n; //to check if i==0 was skipped
      QFont           *font1, *font2, *font3;
@@ -78,6 +75,7 @@ class Gui : public QWidget, public Ui::Gui {
      // defining signals and slots
  
     private slots:
+     void tray_actions();
      void warnings_on();
      void iconActivated(QSystemTrayIcon::ActivationReason reason);
      void showW();
