@@ -40,8 +40,8 @@ int main(int argc, char *argv[]){
        "if there are less than 70 seconds left.<br/><br/>This program uses qdbus to send a "
        "shutdown/reboot/suspend/hibernate request to either the gnome- or "
        "kde-session-manager, to HAL/ConsoleKit/DeviceKit/UPower and if none of these works, the "
-       "command 'sudo shutdown' will be used (note that when sending the shutdown request to HAL or"
-       " ConsoleKit, or the shutdown command is used, the Session will never be saved. If the "
+       "command 'sudo shutdown' will be used (note that when sending the shutdown request to HAL or "
+       "ConsoleKit, or the shutdown command is used, the Session will never be saved. If the "
        "shutdown command is used, the program will only be able to shutdown and reboot). So "
        "if nothing happens when the shutdown- or reboot-time is reached, it means that one "
        "lacks the rights for the shutdown command. In this case one can do the following:"
@@ -57,7 +57,19 @@ int main(int argc, char *argv[]){
        "need to add the following line to the sudoers (as above):"
        "<pre>* ALL = NOPASSWD:/usr/bin/qshutdown</pre><br/>If you should ever forget "
        "your set password, just remove the whole line starting with \"Password\" manually from "
-       "the qshutdown.conf."));
+       "the qshutdown.conf.<br/><br/><b>Hints on usage:</b><br/>One can not close qshutdown, but "
+       "only quit it using the sytem tray icon (indicator) or the key combination Ctrl+Q "
+       "(see hotkeys).<br/>If you want qshutdown to stop \"bugging\" you, just remove the hook from "
+       "\"warnings on?\".<br/><br/><b>Hotkeys:</b><table border=\"1\"><tr><td>Ctrl+I</td><td>(this)"
+       " information window</td></tr><tr><td>Ctrl+Q</td><td>Quit</td></tr><tr><td>Ctrl+P</td>"
+       "<td>Prefereces</td></tr><tr><td>Ctrl+L</td><td>write the run time once into the logfile (works "
+       "only if qshutdown quits. To make it permanent set it in the preferences.)</td></tr><tr>"
+       "<td>Ctrl+S</td><td>set to shutdown</td></tr><tr><td>Ctrl+R</td><td>set to restart</td></tr>"
+       "<tr><td>Ctrl+U</td><td>set to suspend to RAM</td></tr><tr><td>Ctrl+H</td><td>set to hibernate"
+       "</td></tr><tr><td>Ctrl+E</td><td>stop countdown (only if the countdown has started and the admin "
+       "didn't restrict the access)</td></tr><tr><td>Shift+E</td><td>to edit the config file (for this "
+       "a password is necessary. If you are a user, you can set an \"empty password\" (leave the "
+       "password field empty)).</td></tr></table>"));
      QTextDocumentFragment infoDoc;
      infoDoc = QTextDocumentFragment::fromHtml(infoStr);
      QString info = infoDoc.toPlainText();
