@@ -66,11 +66,12 @@ void PassWord::checkPW(){
        close();
      }
      else
-       msgBox->exec();
+       msgBox->show();
 }
 
 void PassWord::update(){
      if(settings->contains("Password")){
+       label->setEnabled(true);
        passwdLineEdit->setEnabled(true);
        changePasswdButton->setText(tr("&Change password"));
      }
