@@ -31,6 +31,8 @@ class PassWord : public QDialog, public Ui::PassWord {
 
     signals:
      void success();
+     void starting();
+     void finishing();
 
     private:
      QSettings      *settings;
@@ -42,6 +44,9 @@ class PassWord : public QDialog, public Ui::PassWord {
      void checkPW();
      void update();
 
+    protected:
+     virtual void showEvent(QShowEvent* show_);
+     virtual void closeEvent(QCloseEvent* close_);
 };
 
 #endif //PASSWD_H
